@@ -33,7 +33,7 @@ use warnings 'once';
 
 use Cwd 'abs_path';
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use App::LXC::Container::Texts;
 
@@ -73,15 +73,20 @@ simplest standard constructor for a singleton
 
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 
+# LXC default configuration read for default network configuration; this is
+# only variable for the unit tests:
+our $_system_default = '/etc/lxc/default.conf';
+
 sub new($)
 {
     unless (defined $singleton)
     {
 	local $_ = shift;
-	$singleton =	{
-		 SYSTEM_COMMON => '/usr/share/lxc/config/common.conf',
-		 SYSTEM_DEFAULT => '/etc/lxc/default.conf',
-		};
+	$singleton =
+	{
+	 SYSTEM_COMMON => '/usr/share/lxc/config/common.conf',
+	 SYSTEM_DEFAULT => $_system_default,
+	};
 	bless $singleton, $_;
     }
     return $singleton;
